Learn R Programming

RAppArmor (version 0.6.0)

aa_change_hat: Change hats

Description

A hat is a subprofile which name starts with a '^'. The difference between hats and profiles is that one can escape (revert) from the hat using the token. Hence this provides more limited security than a profile.

Usage

aa_change_hat(subprofile, magic_token, verbose = TRUE)

Arguments

subprofile
character string identifying the subprofile (hat) name (without the "^")
magic_token
a number that will be the key to revert out of the hat.
verbose
print some C output (TRUE/FALSE)

Examples

Run this code
aa_change_profile("myprofile");
read.table("/etc/group");
aa_change_hat("testhat", 13337);
read.table("/etc/group");
aa_revert_hat(13337);
read.table("/etc/group");

Run the code above in your browser using DataLab