Learn R Programming

RAppArmor (version 0.6.0)

aa_change_profile: Change profiles

Description

This function changes the current R process to an AppArmor profile. Note that this generally is a one way process: most profiles explicitly prevent switching into another profile, otherwise it would defeat the purpose.

Usage

aa_change_profile(profile, verbose = TRUE)

Arguments

profile
character string with the name of the profile.
verbose
print some C output (TRUE/FALSE)

Examples

Run this code
read.table("/etc/passwd");
aa_change_profile("myprofile");
read.table("/etc/passwd");

Run the code above in your browser using DataLab