Learn R Programming

RAppArmor (version 0.6.0)

aa_getcon: Get AppArmor confinement context for the current task

Description

We can use this function to see if there is an AppArmor profile associated with the current process, and in which mode it current is set (enforce, complain, disable).

Usage

aa_getcon(verbose = TRUE)

Arguments

verbose
print some C output (TRUE/FALSE)

Value

  • list with con and mode.

Details

Note that in order for this function to do its work, it needs read access to the attributes of the current process. Hence if a profile is being enforced that is overly strict, this confinement lookup will fail as well :-)