Learn R Programming

RAppArmor (version 0.6.0)

userinfo: Lookup user info

Description

Function looks up uid, gid, and userinfo for a given username.

Usage

userinfo(username, uid, gid)

Arguments

username
character name identifying the loginname of the user.
uid
integer specifying the uid of the user to lookup.
gid
integer specifying the gid to lookup.

Value

  • a parsed row from /etc/passwd